==> scraping-2.1.3-sources.jar: com/tenqube/visual_scraper/thirdparty/mart/MartScrapperImpl.java <==
package com.tenqube.visual_scraper.thirdparty.mart;

import android.content.Context;

import com.ksp.mobilesdkjava.MSDKSystem.SDKAssistSystem.SDKAssistHomePlus;
import com.ksp.mobilesdkjava.MSDKSystem.SDKAssistSystem.SDKAssistManager;
import com.ksp.mobilesdkjava.MSDKSystem.SDKAssistSystem.SDKAssistResult;
import com.ksp.mobilesdkjava.MSDKSystem.SDKAssistSystem.SDKAssistScrapResult;
import com.ksp.mobilesdkjava.MSDKSystem.SDKAssistSystem.SDKAssistSvrType;
import com.ksp.mobilesdkjava.MarketSystem.BOE.Receipt;
import com.ksp.mobilesdkjava.MarketSystem.BOE.ReceiptProduct;
import com.ksp.mobilesdkjava.MarketSystem.Base.e_MarketKeyCode;
import com.ksp.mobilesdkjava.OUtilSystem.EH;
import com.tenqube.visual_scraper.ScrapService;
import com.tenqube.visual_scraper.constants.Constants;
import com.tenqube.visual_scraper.utils.AppExecutors;
import java.io.File;
import java.util.ArrayList;
import java.util.List;
import timber.log.Timber;

public class MartScrapperImpl implements MartScrapper {

    private Context context;
    private static MartScrapper mInstance = null;
    private AppExecutors appExecutors = new AppExecutors();
    private boolean isInit = false;
    SDKAssistManager mgr = null;
    public static MartScrapper getInstance(Context ctx) {

        synchronized (MartScrapperImpl.class) {
            if (mInstance == null) {
                mInstance = new MartScrapperImpl(ctx);
            }
        }
        return mInstance;
    }

    private MartScrapperImpl(Context context) {
        this.context = context;

    }

    @Override
    public void init(ScrapService.Callback<String> callback) {

        if(isInit) {
            callback.onDataLoaded("");
        } else {

            appExecutors.diskIO().execute(() -> {
                String msg = "";
                mgr = new SDKAssistManager();
                File root_file = context.getFilesDir();
                String sdk_path = root_file.getAbsolutePath();
                try {
                    mgr.Init("visual", "4611948F-7E2D-420B-B2AC-6881356BB3EA", sdk_path, context, SDKAssistSvrType.e_SvrType.AZURE  );
                    isInit = true;
                } catch (Exception e) {
                    msg = e.toString();
                } finally {
                    String finalMsg = msg;
                    appExecutors.mainThread().execute(() -> callback.onDataLoaded(finalMsg));
                }
            });
        }

    }

    SDKAssistHomePlus mSdkHpCon = null;

    @Override
    public void requestMobileAuthCode(String phoneNumber, String birth, String name, ScrapService.Callback<Boolean> onResult) throws Exception {

        appExecutors.diskIO().execute(() -> {

            try {

                mSdkHpCon = new SDKAssistHomePlus(phoneNumber, birth, name);

                mSdkHpCon.RequestMobileAuthCode();

                appExecutors.mainThread().execute(() -> {
                    onResult.onDataLoaded(true);
                });

            } catch (Exception e) {
                e.printStackTrace();
                appExecutors.mainThread().execute(() -> {
                    onResult.onDataLoaded(false);
                });
            }
        });

    }

    @Override
    public void startHomeplusLogin(String authCode, ScrapService.Callback<Boolean> onResult) throws Exception {
        appExecutors.diskIO().execute(() -> {
            try {
                EH.ThrowIfFail(mSdkHpCon !=null, "먼저 모바일 인증코드를 요청해야 합니다.");
                mSdkHpCon.LoginByMobileAuthCode(authCode);

                SDKAssistResult ret =  mSdkHpCon.AddBuyerToSDKAssist();

                if (!ret.Success) {
                    throw  ret.Ex;
                }
                appExecutors.mainThread().execute(() -> {
                    onResult.onDataLoaded(true);
                });

            } catch (Exception e) {
                e.printStackTrace();
                appExecutors.mainThread().execute(() -> {
                    onResult.onDataLoaded(false);
                });
            }

        });
    }

    @Override
    public void addUser(int mallId, String id, String password, ScrapService.Callback<String> callback) {

        appExecutors.diskIO().execute(() -> {

            String msg = "";
            try {
                e_MarketKeyCode keyCode = getMarketKeyCode(mallId);
                SDKAssistResult delete = mgr.DeleteBuyer(keyCode, id);
                Timber.i("delete" + delete.Success);

                SDKAssistResult ret1 = mgr.AddBuyer(keyCode, id, password, true);
                Timber.i("ret1" + ret1.Success);


                if(!ret1.Success) {
                    throw ret1.Ex;
                }
            } catch (Exception e) {
                msg = e.toString();
            } finally {
                String finalMsg = msg;
                appExecutors.mainThread().execute(() -> callback.onDataLoaded(finalMsg));
            }
        });
    }

    @Override
    public void start(int mallId, ScrapService.Callback<String> callback) {

        appExecutors.networkIO().execute(() -> {
            String msg = "";
            try {
                SDKAssistScrapResult ret = mgr.ScrapReceipts();
                Timber.i("scrap 결과" + ret.Success + "");
                if(!ret.Success) {
                    throw ret.Ex;
                }
            } catch (UnsupportedOperationException e) {
                msg = "아이디 또는 패스워드를 다시 확인하세요";
            } catch (Exception e) {
                msg = e.toString();
            } finally {
                String finalMsg = msg;
                appExecutors.mainThread().execute(() -> callback.onDataLoaded(finalMsg));
            }
        });
    }

    @Override
    public void getMartItems(int mallId, ScrapService.Callback<List<MartData>> callback) {

        appExecutors.diskIO().execute(() -> {

            List<MartData> results = new ArrayList<>();

            try {
                ArrayList<Receipt> receiptList = mgr.GetScrapedReceiptList();

                if(receiptList != null) {
                    Timber.i("ScrapManager" + receiptList.size());
                    for(Receipt rr: receiptList) {

                        Timber.i("ScrapManager mallId " + mallId);
                        Timber.i("ScrapManager getMallId(rr.MartEnumKeyCode) " + getMallId(rr.MartEnumKeyCode));

                        if(mallId == getMallId(rr.MartEnumKeyCode)) {
                            ArrayList<ReceiptProduct> productArrayList = mgr.GetReceiptProductListByKey(rr.ReceiptKey);

                            Timber.i("ScrapManager productArrayList " + productArrayList.size());

                            for (ReceiptProduct rp : productArrayList) {

                                Timber.i("ScrapManager BuyDate " + rp.BuyDate);
                                Timber.i("ScrapManager InsertDate " + rp.InsertDate);

                                MartData martData = new MartData();
                                martData.barcode = rp.Barcode;
                                martData.buyCount = rp.BuyCount;
                                // 2019-09-02 13:15:00
                                martData.buyDate = rp.BuyDate;
                                martData.insertDate = rp.InsertDate;
                                martData.name = rp.ProductName;
                                martData.price = rp.UnitPrice.doubleValue();
                                martData.receiptKey = rp.ReceiptKey;
                                martData.receiptProductKey = rp.ReceiptProductKey;
                                martData.orderAmount = rp.OrderAmount.toBigInteger().intValue();
                                results.add(martData);
                            }
                        }
                    }
                }

            } catch (Exception e) {
                e.printStackTrace();
            } finally {
                appExecutors.mainThread().execute(() -> callback.onDataLoaded(results));
            }
        });

    }

    @Override
    public void logout(int mId, String userId) {
        appExecutors.diskIO().execute(() -> {

            String msg = "";
            try {
                e_MarketKeyCode keyCode = getMarketKeyCode(mId);
                SDKAssistResult delete = mgr.DeleteBuyer(keyCode, userId);
                Timber.i("delete" + delete.Success);
            } catch (Exception e) {
            }
        });
    }

    private int getMallId(e_MarketKeyCode martKey) {
        if(martKey == e_MarketKeyCode.LotteMCoupon) {
            return Constants.MALL.LotteMart.getMallId();
        } else if(martKey == e_MarketKeyCode.EMartApp ) {
            return Constants.MALL.Emart.getMallId();

        } else if(martKey == e_MarketKeyCode.HomePlus ) {
            return Constants.MALL.Homeplus.getMallId();
        }
        return -1;
    }

    private e_MarketKeyCode getMarketKeyCode(int mallId) {
        if(mallId == Constants.MALL.Emart.getMallId()) {
            return e_MarketKeyCode.EMartApp;
        } else if(mallId == Constants.MALL.Homeplus.getMallId()) {
            return e_MarketKeyCode.HomePlus;
        }
        else {
            return e_MarketKeyCode.LotteMCoupon;
        }
    }


//    private MallEntity getMall(e_MarketKeyCode mktCode) {
//
//        if(mktCode == e_MarketKeyCode.EMartApp) {
//            return new MallEntity("emart", mktCode.name().hashCode(), "https://stimg.emart.com/store/images/new/common/gnb01.png",
//                    "https://stimg.emart.com/store/images/new/common/gnb01.png", false, false, R.drawable.img_eleven_street, "", "");
//
//        } else {
//            return new Mall("롯데M쿠폰", mktCode.name().hashCode(), "https://stimg.emart.com/store/images/new/common/gnb01.png",
//                    "https://stimg.emart.com/store/images/new/common/gnb01.png", false, false, R.drawable.img_eleven_street, "", "");
//
//        }
//    }

}

==> scraping-2.2.4-sources.jar: com/tenqube/visual_scraper/thirdparty/mart/MartScrapperImpl.java <==
package com.tenqube.visual_scraper.thirdparty.mart;

import android.content.Context;

import com.ksp.mobilesdkjava.MSDKSystem.SDKAssistSystem.SDKAssistHomePlus;
import com.ksp.mobilesdkjava.MSDKSystem.SDKAssistSystem.SDKAssistManager;
import com.ksp.mobilesdkjava.MSDKSystem.SDKAssistSystem.SDKAssistResult;
import com.ksp.mobilesdkjava.MSDKSystem.SDKAssistSystem.SDKAssistScrapResult;
import com.ksp.mobilesdkjava.MSDKSystem.SDKAssistSystem.SDKAssistSvrType;
import com.ksp.mobilesdkjava.MarketSystem.BOE.Receipt;
import com.ksp.mobilesdkjava.MarketSystem.BOE.ReceiptProduct;
import com.ksp.mobilesdkjava.MarketSystem.Base.e_MarketKeyCode;
import com.ksp.mobilesdkjava.OUtilSystem.EH;
import com.tenqube.visual_scraper.ScrapService;
import com.tenqube.visual_scraper.constants.Constants;
import com.tenqube.visual_scraper.utils.AppExecutors;
import java.io.File;
import java.util.ArrayList;
import java.util.List;
import timber.log.Timber;

public class MartScrapperImpl implements MartScrapper {

    private Context context;
    private static MartScrapper mInstance = null;
    private AppExecutors appExecutors = new AppExecutors();
    private boolean isInit = false;
    SDKAssistManager mgr = null;
    public static MartScrapper getInstance(Context ctx) {

        synchronized (MartScrapperImpl.class) {
            if (mInstance == null) {
                mInstance = new MartScrapperImpl(ctx);
            }
        }
        return mInstance;
    }

    private MartScrapperImpl(Context context) {
        this.context = context;

    }

    @Override
    public void init(ScrapService.Callback<String> callback) {

        if(isInit) {
            callback.onDataLoaded("");
        } else {

            appExecutors.diskIO().execute(() -> {
                String msg = "";
                mgr = new SDKAssistManager();
                File root_file = context.getFilesDir();
                String sdk_path = root_file.getAbsolutePath();
                try {
                    mgr.Init("visual", "4611948F-7E2D-420B-B2AC-6881356BB3EA", sdk_path, context, SDKAssistSvrType.e_SvrType.AZURE  );
                    isInit = true;
                } catch (Exception e) {
                    msg = e.toString();
                } finally {
                    String finalMsg = msg;
                    appExecutors.mainThread().execute(() -> callback.onDataLoaded(finalMsg));
                }
            });
        }

    }

    SDKAssistHomePlus mSdkHpCon = null;

    @Override
    public void requestMobileAuthCode(String phoneNumber, String birth, String name, ScrapService.Callback<Boolean> onResult) throws Exception {

        appExecutors.diskIO().execute(() -> {

            try {

                mSdkHpCon = new SDKAssistHomePlus(phoneNumber, birth, name);

                mSdkHpCon.RequestMobileAuthCode();

                appExecutors.mainThread().execute(() -> {
                    onResult.onDataLoaded(true);
                });

            } catch (Exception e) {
                e.printStackTrace();
                appExecutors.mainThread().execute(() -> {
                    onResult.onDataLoaded(false);
                });
            }
        });

    }

    @Override
    public void startHomeplusLogin(String authCode, String phoneNumber, ScrapService.Callback<Boolean> onResult) throws Exception {
        appExecutors.diskIO().execute(() -> {
            try {
                EH.ThrowIfFail(mSdkHpCon !=null, "먼저 모바일 인증코드를 요청해야 합니다.");

                SDKAssistResult delete = mgr.DeleteBuyer(e_MarketKeyCode.HomePlus, phoneNumber);
                Timber.i("delete" + delete.Success);

                mSdkHpCon.LoginByMobileAuthCode(authCode);


                SDKAssistResult ret =  mSdkHpCon.AddBuyerToSDKAssist();
                Timber.i("add" + ret.Success);

                if (!ret.Success) {
                    throw  ret.Ex;
                }
                appExecutors.mainThread().execute(() -> {
                    onResult.onDataLoaded(true);
                });

            } catch (Exception e) {
                e.printStackTrace();
                appExecutors.mainThread().execute(() -> {
                    onResult.onDataLoaded(false);
                });
            }

        });
    }

    @Override
    public void addUser(int mallId, String id, String password, ScrapService.Callback<String> callback) {

        appExecutors.diskIO().execute(() -> {

            String msg = "";
            try {
                e_MarketKeyCode keyCode = getMarketKeyCode(mallId);
                SDKAssistResult delete = mgr.DeleteBuyer(keyCode, id);
                Timber.i("delete" + delete.Success);

                SDKAssistResult ret1 = mgr.AddBuyer(keyCode, id, password, true);
                Timber.i("ret1" + ret1.Success);


                if(!ret1.Success) {
                    throw ret1.Ex;
                }
            } catch (Exception e) {
                msg = e.toString();
            } finally {
                String finalMsg = msg;
                appExecutors.mainThread().execute(() -> callback.onDataLoaded(finalMsg));
            }
        });
    }

    @Override
    public void start(int mallId, ScrapService.Callback<String> callback) {

        appExecutors.networkIO().execute(() -> {
            String msg = "";
            try {
                SDKAssistScrapResult ret = mgr.ScrapReceipts();
                Timber.i("scrap 결과" + ret.Success + "");
                if(!ret.Success) {
                    throw ret.Ex;
                }
            } catch (UnsupportedOperationException e) {
                msg = "아이디 또는 패스워드를 다시 확인하세요";
            } catch (Exception e) {
                msg = e.toString();
            } finally {
                String finalMsg = msg;
                appExecutors.mainThread().execute(() -> callback.onDataLoaded(finalMsg));
            }
        });
    }

    @Override
    public void getMartItems(int mallId, ScrapService.Callback<List<MartData>> callback) {

        appExecutors.diskIO().execute(() -> {

            List<MartData> results = new ArrayList<>();

            try {
                ArrayList<Receipt> receiptList = mgr.GetScrapedReceiptList();

                if(receiptList != null) {
                    Timber.i("ScrapManager" + receiptList.size());
                    for(Receipt rr: receiptList) {

                        Timber.i("ScrapManager mallId " + mallId);
                        Timber.i("ScrapManager getMallId(rr.MartEnumKeyCode) " + getMallId(rr.MartEnumKeyCode));

                        if(mallId == getMallId(rr.MartEnumKeyCode)) {
                            ArrayList<ReceiptProduct> productArrayList = mgr.GetReceiptProductListByKey(rr.ReceiptKey);

                            Timber.i("ScrapManager productArrayList " + productArrayList.size());

                            for (ReceiptProduct rp : productArrayList) {

                                Timber.i("ScrapManager BuyDate " + rp.BuyDate);
                                Timber.i("ScrapManager InsertDate " + rp.InsertDate);

                                MartData martData = new MartData();
                                martData.barcode = rp.Barcode;
                                martData.buyCount = rp.BuyCount;
                                // 2019-09-02 13:15:00
                                martData.buyDate = rp.BuyDate;
                                martData.insertDate = rp.InsertDate;
                                martData.name = rp.ProductName;
                                martData.price = rp.UnitPrice.doubleValue();
                                martData.receiptKey = rp.ReceiptKey;
                                martData.receiptProductKey = rp.ReceiptProductKey;
                                martData.orderAmount = rp.OrderAmount.toBigInteger().intValue();
                                results.add(martData);
                            }
                        }
                    }
                }

            } catch (Exception e) {
                e.printStackTrace();
            } finally {
                appExecutors.mainThread().execute(() -> callback.onDataLoaded(results));
            }
        });

    }

    @Override
    public void logout(int mId, String userId) {
        appExecutors.diskIO().execute(() -> {

            String msg = "";
            try {
                e_MarketKeyCode keyCode = getMarketKeyCode(mId);
                SDKAssistResult delete = mgr.DeleteBuyer(keyCode, userId);
                Timber.i("delete" + delete.Success);
            } catch (Exception e) {
            }
        });
    }

    private int getMallId(e_MarketKeyCode martKey) {
        if(martKey == e_MarketKeyCode.LotteMCoupon) {
            return Constants.MALL.LotteMart.getMallId();
        } else if(martKey == e_MarketKeyCode.EMartApp ) {
            return Constants.MALL.Emart.getMallId();

        } else if(martKey == e_MarketKeyCode.HomePlus ) {
            return Constants.MALL.Homeplus.getMallId();
        }
        return -1;
    }

    private e_MarketKeyCode getMarketKeyCode(int mallId) {
        if(mallId == Constants.MALL.Emart.getMallId()) {
            return e_MarketKeyCode.EMartApp;
        } else if(mallId == Constants.MALL.Homeplus.getMallId()) {
            return e_MarketKeyCode.HomePlus;
        }
        else {
            return e_MarketKeyCode.LotteMCoupon;
        }
    }


//    private MallEntity getMall(e_MarketKeyCode mktCode) {
//
//        if(mktCode == e_MarketKeyCode.EMartApp) {
//            return new MallEntity("emart", mktCode.name().hashCode(), "https://stimg.emart.com/store/images/new/common/gnb01.png",
//                    "https://stimg.emart.com/store/images/new/common/gnb01.png", false, false, R.drawable.img_eleven_street, "", "");
//
//        } else {
//            return new Mall("롯데M쿠폰", mktCode.name().hashCode(), "https://stimg.emart.com/store/images/new/common/gnb01.png",
//                    "https://stimg.emart.com/store/images/new/common/gnb01.png", false, false, R.drawable.img_eleven_street, "", "");
//
//        }
//    }

}
